:mod:`art.attacks.evasion`
==========================
.. automodule:: art.attacks.evasion

Adversarial Patch
-----------------
.. autoclass:: AdversarialPatch
   :members:
   :special-members:

Adversarial Patch - Numpy
-------------------------
.. autoclass:: AdversarialPatchNumpy
   :members:
   :special-members:

Adversarial Patch - TensorFlowV2
--------------------------------
.. autoclass:: AdversarialPatchTensorFlowV2
   :members:
   :special-members:

Auto Attack
-----------
.. autoclass:: AutoAttack
   :members:
   :special-members:

Auto Projected Gradient Descent (Auto-PGD)
------------------------------------------
.. autoclass:: AutoProjectedGradientDescent
   :members:
   :special-members:

Decision-Based Attack / Boundary Attack
---------------------------------------
.. autoclass:: BoundaryAttack
   :members:
   :special-members:

Carlini and Wagner L_2 Attack
-----------------------------
.. autoclass:: CarliniL2Method
   :members:
   :special-members:

Carlini and Wagner L_inf Attack
-------------------------------
.. autoclass:: CarliniLInfMethod
   :members:
   :special-members:

Decision Tree Attack
--------------------
.. autoclass:: DecisionTreeAttack
   :members:
   :special-members:

DeepFool
--------
.. autoclass:: DeepFool
   :members:
   :special-members:

DPatch
------
.. autoclass:: DPatch
   :members:
   :special-members:

Elastic Net Attack
------------------
.. autoclass:: ElasticNet
   :members:
   :special-members:

Fast Gradient Method (FGM)
--------------------------
.. autoclass:: FastGradientMethod
   :members:
   :special-members:

Feature Adversaries
-------------------
.. autoclass:: FeatureAdversaries
   :members:
   :special-members:

Frame Saliency Attack
---------------------
.. autoclass:: FrameSaliencyAttack
   :members:
   :special-members:

HopSkipJump Attack
------------------
.. autoclass:: HopSkipJump
   :members:
   :special-members:

High Confidence Low Uncertainty Attack
--------------------------------------
.. autoclass:: HighConfidenceLowUncertainty
   :members:
   :special-members:

Basic Iterative Method (BIM)
----------------------------
.. autoclass:: BasicIterativeMethod
   :members:
   :special-members:

Projected Gradient Descent (PGD)
--------------------------------
.. autoclass:: ProjectedGradientDescent
   :members:
   :special-members:

Projected Gradient Descent (PGD) - Numpy
----------------------------------------
.. autoclass:: ProjectedGradientDescentNumpy
   :members:
   :special-members:

Projected Gradient Descent (PGD) - PyTorch
------------------------------------------
.. autoclass:: ProjectedGradientDescentPyTorch
   :members:
   :special-members:

Projected Gradient Descent (PGD) - TensorFlowV2
-----------------------------------------------
.. autoclass:: ProjectedGradientDescentTensorFlowV2
   :members:
   :special-members:

NewtonFool
----------
.. autoclass:: NewtonFool
   :members:
   :special-members:

PixelAttack
-----------
.. autoclass:: PixelAttack
   :members:
   :special-members:

ThresholdAttack
---------------
.. autoclass:: ThresholdAttack
   :members:
   :special-members:

Jacobian Saliency Map Attack (JSMA)
-----------------------------------
.. autoclass:: SaliencyMapMethod
   :members:
   :special-members:

Shadow Attack
-------------
.. autoclass:: ShadowAttack
   :members:
   :special-members:

ShapeShifter Attack
-------------------
.. autoclass:: ShapeShifter
   :members:
   :special-members:

SimBA Attack
------------
.. autoclass:: SimBA
   :members:
   :special-members:

Spatial Transformations Attack
------------------------------
.. autoclass:: SpatialTransformation
   :members:
   :special-members:

Square Attack
-------------
.. autoclass:: SquareAttack
   :members:
   :special-members:

Targeted Universal Perturbation Attack
--------------------------------------
.. autoclass:: TargetedUniversalPerturbation
   :members:
   :special-members:

Universal Perturbation Attack
-----------------------------
.. autoclass:: UniversalPerturbation
   :members:
   :special-members:

Virtual Adversarial Method
--------------------------
.. autoclass:: VirtualAdversarialMethod
   :members:
   :special-members:

Wasserstein Attack
------------------
.. autoclass:: Wasserstein
   :members:
   :special-members:

Zeroth-Order Optimization Attack (ZOO)
--------------------------------------
.. autoclass:: ZooAttack
   :members:
   :special-members:
